GroupKeyInfo class

Contains information of a FROST key required for all participants and the coordinator. This includes the group public key and the threshold number.

Inheritance
Implemented types

Constructors

GroupKeyInfo({required ECCompressedPublicKey groupKey, required int threshold})
Takes the FROST key information. If this information is invalid InvalidKeyInfo may be thrown.
GroupKeyInfo.fromBytes(Uint8List bytes)
Convenience constructor to construct from serialised bytes.
GroupKeyInfo.fromHex(String hex)
Convenience constructor to construct from encoded hex.
GroupKeyInfo.fromReader(BytesReader reader)

Properties

groupKey → ECCompressedPublicKey
The public key of the overall FROST key
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size int
Obtains the cached size of the object
no setterinherited
threshold int
The number of signers required for a signature
final

Methods

compareTo(KeyInfoWithGroupKey other) int
Compares this object to another object.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toBytes() Uint8List
Obtains a cached Uint8List with data serialized for this object
inherited
toHex() String
inherited
toString() String
A string representation of this object.
inherited
tweak(Uint8List scalar) GroupKeyInfo?
Tweaks the group key by a scalar. null may be returned if the scalar was crafted to lead to an invalid public key.
override
write(Writer writer) → void
Override to write data into writer

Operators

operator ==(Object other) bool
The equality operator.
inherited