SigningCommitment class
The commitment to the signature nonce to be used for signing. This should be shared with the signature aggregator.
- Inheritance
-
- Object
- RustObjectWrapper<
SigningCommitments> - WritableRustObjectWrapper<
SigningCommitments> - SigningCommitment
Constructors
- SigningCommitment.fromBytes(Uint8List data)
- Reads the serialised commitment from a participant and throws InvalidSigningCommitment if invalid.
- SigningCommitment.fromUnderlying(SigningCommitments _underlying)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- underlying → SigningCommitments
-
no setterinherited
Methods
-
dispose(
) → void -
May be called when the underlying rust object is no longer needed to clear
memory before GC.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serializeImpl(
) → Uint8List -
Obtains serialised data for the commitment that can be shared with
the signature aggregator.
override
-
toBytes(
) → Uint8List -
Obtain the serailised bytes for this object
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited